@@ -14,7 +14,4 @@ class charitable_deduction_for_non_itemizers(Variable):
         p = parameters(period).gov.irs.deductions.itemized.charity
         cash_donations = add(tax_unit, period, ["charitable_cash_donations"])
         filing_status = tax_unit("filing_status", period)
-        return min_(
-            p.non_itemizers_amount[filing_status],
-            cash_donations,
-        )
+        return min_(p.non_itemizers_amount[filing_status], cash_donations)
