@@ -14,4 +14,8 @@ class ny_agi_subtractions(Variable):
     )
     defined_for = StateCode.NY
 
-    adds = "gov.states.ny.tax.income.agi.subtractions.sources"
+    def formula(tax_unit, period, parameters):
+        p = parameters(period).gov.states.ny.tax.income.agi.subtractions
+        total_subtractions = add(tax_unit, period, p.sources)
+        # Prevent negative subtractions from acting as additions
+        return max_(0, total_subtractions)
